@@ -2,12 +2,22 @@ import uuid
 
 from django.db import models
 from django.db.models.deletion import PROTECT
+from edc_adverse_event.model_mixins import (
+    AeFollowupModelMixin,
+    AeInitialModelMixin,
+    AesiModelMixin,
+    AeSusarModelMixin,
+    AeTmgModelMixin,
+    DeathReportModelMixin,
+    DeathReportTmgModelMixin,
+    DeathReportTmgSecondModelMixin,
+)
 from edc_appointment.models import Appointment
 from edc_consent.field_mixins import PersonalFieldsMixin
 from edc_consent.field_mixins.identity_fields_mixin import IdentityFieldsMixin
 from edc_consent.model_mixins import ConsentModelMixin
 from edc_constants.choices import YES_NO
-from edc_crf.crf_with_action_model_mixin import CrfWithActionModelMixin
+from edc_crf.model_mixins import CrfWithActionModelMixin
 from edc_identifier.managers import SubjectIdentifierManager
 from edc_identifier.model_mixins import UniqueSubjectIdentifierFieldMixin
 from edc_lab.model_mixins import RequisitionModelMixin
@@ -54,14 +64,6 @@ class SubjectOffstudy(OffstudyModelMixin, BaseUuidModel):
         pass
 
 
-class DeathReport(UniqueSubjectIdentifierFieldMixin, SiteModelMixin, BaseUuidModel):
-
-    objects = SubjectIdentifierManager()
-
-    def natural_key(self):
-        return (self.subject_identifier,)
-
-
 class SubjectConsent(
     ConsentModelMixin,
     PersonalFieldsMixin,
@@ -77,7 +79,7 @@ class SubjectConsent(
     history = HistoricalRecords()
 
     def natural_key(self):
-        return (self.subject_identifier,)
+        return tuple(self.subject_identifier)
 
 
 class SubjectReconsent(
@@ -95,7 +97,7 @@ class SubjectReconsent(
     history = HistoricalRecords()
 
     def natural_key(self):
-        return (self.subject_identifier,)
+        return tuple(self.subject_identifier)
 
 
 class SubjectVisit(
@@ -205,3 +207,55 @@ class RedirectModel(BaseUuidModel):
 class RedirectNextModel(BaseUuidModel):
 
     subject_identifier = models.CharField(max_length=25)
+
+
+class AeInitial(AeInitialModelMixin, BaseUuidModel):
+    class Meta(AeInitialModelMixin.Meta):
+        pass
+
+
+class AeFollowup(AeFollowupModelMixin, BaseUuidModel):
+
+    ae_initial = models.ForeignKey(AeInitial, on_delete=PROTECT)
+
+    class Meta(AeFollowupModelMixin.Meta):
+        pass
+
+
+class Aesi(AesiModelMixin, BaseUuidModel):
+
+    ae_initial = models.ForeignKey(AeInitial, on_delete=PROTECT)
+
+    class Meta(AesiModelMixin.Meta):
+        pass
+
+
+class AeSusar(AeSusarModelMixin, BaseUuidModel):
+
+    ae_initial = models.ForeignKey(AeInitial, on_delete=PROTECT)
+
+    class Meta(AeSusarModelMixin.Meta):
+        pass
+
+
+class AeTmg(AeTmgModelMixin, BaseUuidModel):
+
+    ae_initial = models.ForeignKey(AeInitial, on_delete=PROTECT)
+
+    class Meta(AeTmgModelMixin.Meta):
+        pass
+
+
+class DeathReport(DeathReportModelMixin, BaseUuidModel):
+    class Meta(DeathReportModelMixin.Meta):
+        pass
+
+
+class DeathReportTmg(DeathReportTmgModelMixin, BaseUuidModel):
+    class Meta(DeathReportTmgModelMixin.Meta):
+        pass
+
+
+class DeathReportTmgSecond(DeathReportTmgSecondModelMixin, BaseUuidModel):
+    class Meta(DeathReportTmgSecondModelMixin.Meta):
+        pass
